/*
 * BitCtrl-Funktionsbibliothek
 * Copyright (C) 2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.interpreter;

import java.util.*;

/**
 * Basisklasse aller Symbole des Interpeters.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker, Schumann
 */
public interface Ausdruck<T> {

	/**
	 * Bestimmt Rekursiv die Menge der Termsymbole im Ausdruck, die
	 * Variablen darstellen.
	 *
	 * @param ausdruck
	 *            Ein beliebiger Ausdruck
	 * @return Menge der Variablennamen
	 */
	static Set<String> getVariablen(final Ausdruck<?> ausdruck) {
		Set<String> variablen = new HashSet<>();
		if (ausdruck instanceof Variable) {
			variablen.add(((Variable) ausdruck).getName());
		} else  {
			for (final Ausdruck<?> a : ausdruck.getNachfolger()) {
				variablen.addAll(getVariablen(a));
			}
		}
		return variablen;
	}

	/**
	 * Gibt eine Liste der verschachtelten Ausdr&uuml;cke zur&uuml;ck.
	 *
	 * @return Liste der Ausdr&uuml;cke <em>direkt</em> unter diesen Ausdruck.
	 *         Die Methode arbeiten im Gegensatz zu {@link #interpret(Kontext)}
	 *         nicht rekursiv.
	 */
	default List<? extends Ausdruck<?>> getNachfolger() {
		return Collections.emptyList();
	}

	/**
	 * Interpretiert den Ausdruck im gegebenen Kontext.
	 *
	 * @param kontext
	 *            Kontext, indem der Ausdruck ausgewertet wird
	 * @return Wert des interpretierten Ausdrucks
	 */
	T interpret(Kontext kontext);

}
